- [x] BPS file patcher (to apply base patch)
- [x] Tie animated palettes to tileset palettes where possible
- [x] Ability to overwrite credits text
- [ ] Allow parsing/writing non-English text
- [x] Display seed hash on file select screen
- [x] Option to start with stereo audio
- [x] Option to disable music
- [x] Elevator connection shuffle
- [ ] Door lock shuffle
  - [x] Existing lock types
  - [ ] New lock types
- [x] Tube connection shuffle
